/* Copyright (c) 2007 Matthew Burnside.

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE. */

var query;
var rescnt;

var proc;
var procreq;

var sel = new Array();
var docs;
var base = "http://www.matthewburnside.org/photos";

function parseURL() {
	var url = location.href;
	var args, params, equ, i;

	if (url.indexOf('?') == -1) // no arguments
	    return;

	args = url.split('?');
	if (args[1].length > 0) {
	    params = args[1].split("&");
	    for (i = 0; i < params.length; i++) {
		equ = params[i].split("=");
		switch (equ[0]) {
		case 'q':
		    query = equ[1].split("+");
		    break;
		case 'h':
		    if (equ[1] == "n")
			showAll = true;
		    break;
		default:
		    break;
		}
	    }
	}
	if (query)
	    searchEngine(null, "init");
}

function searchEngine(doc, state) {
        switch(state) {
        case "init":
            init();
            procreq = makeRequest(base + "/album/album.xsl", searchEngine,
		"style");
            break;
        case "style":
            if (typeof XSLTProcessor != "undefined") {
                proc = new XSLTProcessor();
                proc.importStylesheet(doc);
            }
            dir = docs.shift();
            if (dir != null)
                makeRequest(dir + "/index.xml", searchEngine, "next");
            else
                searchEngine(null, "end");
            break;
        case "next":
            search(doc);
            dir = docs.shift();
            if (dir != null)
                makeRequest(dir + "/index.xml", searchEngine, "next");
            else
                searchEngine(null, "end");
            break;
        case "end":
            var timeEnd = new Date();
            document.getElementById("error").innerHTML = "Results: " +
                rescnt + " (" + ((timeEnd - timeStart) / 1000) + " seconds)";
            document.body.style.cursor = "auto";
            break;
        default:
            break;
        }
}

function init() {
        var albums, i;
        rescnt = 0;

        document.getElementById("content").style.display = "none";
        document.getElementById("results").style.display = "block";
        document.body.style.cursor = "progress";

        albums = getElementsByClass("album");

        docs = new Array();
        for (i = 0; i != albums.length; i++)
            docs.push(albums[i].firstChild.getAttribute("href"));

        document.getElementById("error").innerHTML = "Searching:  0 results.";
        timeStart = new Date();
}

function getElementsByClass(searchClass, node, tag) {
        var classElements = new Array();
        var i, j, els, elsLen, pattern;

        if (node == null)
            node = document;
        if (tag == null)
            tag = '*';
        els = node.getElementsByTagName(tag);
        elsLen = els.length;
        pattern = new RegExp('(^|\\s)' + searchClass + '(\\s|$)');
        for (i = 0, j = 0; i < elsLen; i++) {
            if (pattern.test(els[i].className)) {
                classElements[j] = els[i];
                j++;
            }
        }
        return classElements;
}

function makeRequest(url, handler, state) {
        var req = new XMLHttpRequest();

        if (req == null) {
            alert("Error: your browser does not support Ajax.");
            return null;
        }

        req.onreadystatechange = function() {
            if (req.readyState == 4) {
                if (req.status != 200) {
                    alert("File not found: " + url);
                }
                handler(req.responseXML, state);
            }
        }
        req.open("GET", url, true);
        req.send(null);
        return req;
}

function search(doc) {
        var i, j, k, imgs, tags;

        imgs = doc.getElementsByTagName("image");

    nextimg:
        for (i = 0; i != imgs.length; i++) {
            tags = imgs[i].getElementsByTagName("tag");
    nextquery:
            for (j = 0; j != query.length; j++) {
                for (k = 0; k != tags.length; k++) {
                    if (query[j] == tags[k].childNodes[0].nodeValue)
                        continue nextquery;
		}
                continue nextimg;
            }

            if (imgs[i].getAttribute("hidden") != "true") {
                rescnt++;
                document.getElementById("error").innerHTML = "Searching... " +
                    rescnt + " results.";
                addResult(imgs[i]);
            }
        }
}

function addResult(result) {
        var fn, tm, r;

        fn = result.getElementsByTagName("filename");
        fn[0].firstChild.nodeValue = dir + "/" + fn[0].firstChild.nodeValue;

        tm = result.getElementsByTagName("thumb");
        if (tm[0].firstChild != null)
            tm[0].firstChild.nodeValue = dir + "/"+tm[0].firstChild.nodeValue;

        r = document.createElement("div");

        if (proc) {
            r.innerHTML = "";
            r.appendChild(proc.transformToFragment(result, document));
        } else
            r.innerHTML = result.transformNode(procreq.responseXML);

        document.getElementById("results").appendChild(r);
}


/* Functions for edit **********************************************/

function edit() {
        editEngine(null, "init");
}


function editEngine(doc, state) {
        switch(state) {
        case "init":
            makeRequest(base + "/album/album.xsl", editEngine, "style");
            break;
        case "style":
            proc = new XSLTProcessor();
            proc.importStylesheet(doc);
            makeRequest("index.xml", editEngine, "index");
            break;
        case "index":
	    proc.setParameter(null, "album-mode", "edit");
	    document.body.innerHTML = "";
	    document.body.appendChild(proc.transformToFragment(doc, document));
            break;
        default:
            break;
        }
}


function generate() {
	var n, main, txt, frag;
	var win = window.open("");
	var ser = new XMLSerializer();
	win.focus();

	main = document.getElementById("content");

	n = main.getElementsByTagName("input");
	for (var i = 0; i < n.length; i++) {
	    n[i].setAttribute("val", n[i].value);

	    if (n[i].getAttribute("class") == "tags")
		n[i].setAttribute("val", n[i].value.replace(/[\s,]+/g, ","));

	    if (n[i].getAttribute("class") == "hid") {
		n[i].setAttribute("val", n[i].checked ? "true" : "false");
	    }
	}

	frag = proc.transformToFragment(main, document);
	txt = ser.serializeToString(frag);

	txt = txt.replace("<", "&lt;", "g");
	txt = txt.replace(">", "&gt;", "g");
	txt = txt.replace(/(\r\n|[\r\n])/g, "<br/>");

	win.document.write(txt);
	win.document.close();
}


function hide(e) {
	img = document.evaluate(
	    "ancestor::div[@class='image-container']/a[@class='image']/img", e,
	    null, XPathResult.ANY_TYPE, null).iterateNext();

	if (e.checked)
	    img.style.opacity = "0.25";
	else
	    img.style.opacity = "1.0";
}


function addTag() {
	var i, t, tag;

	if (sel.length > 0)
	    tags = prompt("Tags:");

	for (i = 0; i < sel.length; i++) {
	    t = document.evaluate("./span/input[@class='tags']",
		sel[i], null, XPathResult.ANY_TYPE, null).iterateNext();

	    t.value = tagUnion(t.value, tags);
	}
}


function removeTag() {
	var i, t, tag;

	if (sel.length > 0)
	    tags = prompt("Remove tags:");

	for (i = 0; i < sel.length; i++) {
	    t = document.evaluate("./span/input[@class='tags']",
		sel[i], null, XPathResult.ANY_TYPE, null).iterateNext();

	    t.value = tagSubtract(t.value, tags);
	}
}


function tagUnion(a, b) {
	var na, nb, n, i, unduped, uniques;

	na = a.split(/[\s,]+/);
	nb = b.split(/[\s,]+/);

	nt = na.concat(nb);

	unduped = new Object();
	for (i = 0; i < nt.length; i++)
	    unduped[nt[i]] = nt[i];

	uniques = "";
	for (var k in unduped)
	    uniques += unduped[k] + ", ";

	uniques = uniques.replace(/^, /, "");
	return uniques.replace(/, $/, "");
}


function tagSubtract(a, b) { // remove any elements in b from a
	var na, nb, n, i, r;

	na = a.split(/[\s,]+/);
	nb = b.split(/[\s,]+/);

	for (i = 0; i < nb.length; i++) {
	    n = na.indexOf(nb[i]);
	    if (n > -1)
		na.splice(n, 1);
	}

	r = "";
	for (i = 0; i < na.length; i++)
	    r += na[i] + ", ";

	return r.replace(/, $/, "");
}


function selectImage(e) {
	var p, i;

	p = document.evaluate("ancestor::div[@class='image-container']", e,
	    null, XPathResult.ANY_TYPE, null).iterateNext();

	i = document.evaluate("./a[@class='image']/img", p, null,
	    XPathResult.ANY_TYPE, null).iterateNext();

	if (e.checked) {
	    i.setAttribute("class", "image-selected");
	    sel.push(p);
	} else {
	    i.setAttribute("class", "image");
	    sel.splice(sel.indexOf(p), 1);
	}
}


function selectAll() {
	var p, it, n, b, i;

	p = document.evaluate("//div[@class='image-container']", document,
	    null, XPathResult.ANY_TYPE, null);

	it = p.iterateNext();
	while(it) {
	    if (sel.indexOf(it) == -1)
		sel.push(it);
	    it = p.iterateNext();
	}

	for (n = 0; n < sel.length; n++) {
	    b = document.evaluate("./div[@class='selbox']/input", sel[n], null,
		XPathResult.ANY_TYPE, null).iterateNext();

	    i = document.evaluate("./a[@class='image']/img", sel[n], null,
		XPathResult.ANY_TYPE, null).iterateNext();

	    b.checked = true;
	    i.setAttribute("class", "image-selected");
	}
}


function selectNone() {
	var n, b, i;

	while (sel.length > 0) {
	    n = sel.shift();

	    b = document.evaluate("./div[@class='selbox']/input", n, null,
		XPathResult.ANY_TYPE, null).iterateNext();

	    i = document.evaluate("./a[@class='image']/img", n, null,
		XPathResult.ANY_TYPE, null).iterateNext();

	    b.checked = false;
	    i.setAttribute("class", "image");
	}
}


function moveUp() {
	var par, sib;

	selSort();

	par = sel[0].parentNode;
	sib = sel[0].previousSibling;

	if (sib == null || sib.getAttribute("class") != "image-container")
	    return;

	for (i = 0; i < sel.length; i++) {
	    sib = sel[i].previousSibling;
	    par.removeChild(sel[i]);
	    par.insertBefore(sel[i], sib);
	}
}


function moveDown() {
	var par, sib;

	selSort();

	par = sel[0].parentNode;
	sib = sel[sel.length - 1].nextSibling;

	if (sib == null || sib.getAttribute("class") != "image-container")
	    return;

	for (i = sel.length - 1; i >= 0; i--) {
	    sib = sel[i].nextSibling;
	    par.removeChild(sel[i]);
	    par.insertBefore(sel[i], sib.nextSibling);
	}
}



function selSort() {
	var newsel = new Array();

	p = document.evaluate("//div[@class='image-container']", document,null,
	    XPathResult.ANY_TYPE, null);

	it = p.iterateNext();
	while(it) {
	    if (sel.indexOf(it) != -1)
		newsel.push(it);
	    it = p.iterateNext();
	}
	sel = newsel;
}
