<?xml version="1.0" encoding="UTF-8"?>

<!-- Copyright (c) 2007 Matthew Burnside.

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE. -->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html"
    doctype-system="http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"
    doctype-public="-//W3C//DTD XHTML 1.1//EN" indent="yes"/>

<xsl:include href="album-conf.xml"/>
<xsl:param name="album-mode">show</xsl:param>

<!-- Shared templates -->

<xsl:template match="/">
    <html>
    <head>
    <title><xsl:value-of select="$title"/></title>
    <link rel="stylesheet" type="text/css"
	href="{$base}/album/album-simple.css"/>
    <script type="text/javascript" language="javascript"
	src="{$base}/album/album.js"/>
    </head>

    <xsl:choose>
    <xsl:when test="index">
        <xsl:apply-templates select="index"/>
    </xsl:when>
    <xsl:when test="album">
        <xsl:apply-templates select="album"/>
    </xsl:when>
    </xsl:choose>

    </html>
</xsl:template>


<xsl:template name="header">
    <xsl:param name="loc"/>

    <div id="header">
    <xsl:choose>
    <xsl:when test="$loc = 'index'">
        <a href=""><xsl:value-of select="$title"/></a>
    </xsl:when>
    <xsl:when test="$loc = 'album'">
        <a href=".."><xsl:value-of select="$title"/></a>
    </xsl:when>
    </xsl:choose>
    </div>
</xsl:template>


<xsl:template name="thumb">
    <xsl:variable name="thumb">
    <xsl:choose>
    <xsl:when test="@type='pic'">
        <xsl:value-of select="thumb"/>
    </xsl:when>
    <xsl:when test="@type='mov'">
        <xsl:value-of select="$base"/>
	<xsl:text>/album/movie.thumb.jpg</xsl:text>
    </xsl:when>
    </xsl:choose>
    </xsl:variable>

    <a class="image" href="{filename}" type="{@type}">
    <img src="{$thumb}" class="thumb">
    <xsl:if test="@hidden = 'true'">
        <xsl:attribute name="style">opacity:0.25</xsl:attribute>
    </xsl:if>
    </img>
    <xsl:text> </xsl:text>
    </a>
</xsl:template>


<!-- Translations for the index -->

<xsl:template match="index">
    <body onload="parseURL();">

    <div id="frame">
    <xsl:call-template name="header">
        <xsl:with-param name="loc">index</xsl:with-param>
    </xsl:call-template>

    <div id="results"></div>
    <div id="content">
    <div id="description"><xsl:value-of select="description"/></div>
    <xsl:apply-templates select="albums/album" mode="index"/>
    </div>

    <div id="sidebar">
    <form style="margin:0;">
    <input type="text" name="q"/>
    <input type="button" value="Search" onclick="location.href='?q='+q.value"/>
    </form>
    <div id="error"></div>
    </div>

    </div>
    </body>
</xsl:template>


<xsl:template match="album" mode="index">
    <div class="album-container">
    <xsl:variable name="prev" select="preceding-sibling::album[1]/date"/>
    <xsl:variable name="p" select="concat(substring-before($prev, ' '),
        substring-after($prev, ','))"/>
    <xsl:variable name="c" select="concat(substring-before(date, ' '),
        substring-after(date, ','))"/>

    <xsl:if test="not($p = $c)">
        <div class="date"><xsl:value-of select="$c"/></div>
    </xsl:if>

    <div class="album">
    <a href="./{link}/."><xsl:value-of select="title"/></a>
    </div>
    </div>
</xsl:template>



<!-- Translations for an album -->

<xsl:template match="album">
    <body>
    <div id="edit">
    <a href="javascript:edit();">#</a>
    </div>

    <div id="frame">
    <xsl:call-template name="header">
        <xsl:with-param name="loc">album</xsl:with-param>
    </xsl:call-template>

    <div id="content">
    <xsl:choose>
    <xsl:when test="$album-mode = 'show'">
	<div id="description">
	<div class="date"><xsl:value-of select="date"/></div>
	<div class="title"><a href="."><xsl:value-of select="title"/></a></div>
	</div>
	<xsl:apply-templates select="images/image"/>
    </xsl:when>
    <xsl:when test="$album-mode = 'edit'">
	<div id="description">
	<input type="text" id="dateEdit" value="{date}"  class="date"/>
	<input type="text" id="titleEdit" value="{title}" class="title"/>
	</div>
	<xsl:apply-templates select="images/image" mode="edit"/>
    </xsl:when>
    </xsl:choose>
    </div>

    <div id="sidebar">
    <xsl:if test="$album-mode = 'edit'">
	<a style="text-decoration:underline" href="javascript:generate();">
	Generate
	</a><br/><br/>
	<a style="text-decoration:underline" href="javascript:addTag();">
	Add tag
	</a>&#160;
	<a style="text-decoration:underline" href="javascript:removeTag();">
	Remove tag
	</a><br/>
	Select:
	<a href="javascript:selectAll();">All</a>,
	<a href='javascript:selectNone();'>None</a><br/>
	Move:
	<a href='javascript:moveUp()'>Up</a>,
	<a href='javascript:moveDown()'>Down</a>
    </xsl:if>
    </div>
    <div id="error"></div>
    </div>

    </body>
</xsl:template>


<xsl:template match="image">
    <xsl:if test="@hidden = 'false' or $show-hidden-images = 'true'">

    <div class="image-container">
    <xsl:call-template name="thumb"/>

    <div class="tags">
    <xsl:for-each select="tags/tag">
        <a href="{$base}/?q={.}">
        <xsl:value-of select="."/>
        </a>
        <xsl:if test=". != ../tag[last()]">, </xsl:if>
    </xsl:for-each>
    </div>

    <xsl:if test="description != ''">
    <div class="caption"><xsl:value-of select="description"/></div>
    </xsl:if>

    </div>
    </xsl:if>
</xsl:template>


<xsl:template match="image" mode="edit">
    <div class="image-container">
    <div class="selbox">
    <xsl:element name="input">
        <xsl:attribute name="type">checkbox</xsl:attribute>
        <xsl:attribute name="value">selected</xsl:attribute>
        <xsl:attribute name="class">select</xsl:attribute>
        <xsl:attribute name="onclick">selectImage(this);</xsl:attribute>
    </xsl:element>
    </div>
    <xsl:call-template name="thumb"/>
    <xsl:text> </xsl:text>

    <xsl:variable name="tag">
    <xsl:for-each select="tags/tag">
        <xsl:value-of select="."/>
        <xsl:if test=". != ../tag[last()]">, </xsl:if>
    </xsl:for-each>
    </xsl:variable>
    <span><input type="text" value="{$tag}" class="tags"/></span>

    <span class="hidebox">
    <span class="hidelabel">Hide:</span>
    <xsl:element name="input">
        <xsl:attribute name="type">checkbox</xsl:attribute>
        <xsl:attribute name="value">hidden</xsl:attribute>
        <xsl:attribute name="class">hid</xsl:attribute>
        <xsl:attribute name="onclick">hide(this);</xsl:attribute>
        <xsl:if test="@hidden='true'">
            <xsl:attribute name="checked">checked</xsl:attribute>
        </xsl:if>
    </xsl:element>
    </span>
    <div class="desc">
    <input type="text" value="{description}" class="caption"/>
    </div>
    </div>
</xsl:template>


<!-- Translation back to XML -->


<xsl:template match="div">
    <xsl:text>&lt;?xml version="1.0" encoding="ISO-8859-1"?&gt;
    &lt;?xml-stylesheet type="text/xsl" href="../album.xsl"?&gt;
    </xsl:text>

    <xsl:text>
    &lt;album&gt;
    </xsl:text>

    <xsl:text>&lt;title&gt;</xsl:text>
    <xsl:value-of select="./div/input[@id='titleEdit']/@val"/>
    <xsl:text>&lt;/title&gt;
    </xsl:text>

    <xsl:text>&lt;date&gt;</xsl:text>
    <xsl:value-of select="./div/input[@id='dateEdit']/@val"/>
    <xsl:text>&lt;/date&gt;
    &lt;images&gt;

    </xsl:text>

    <xsl:for-each select="./div[@class='image-container']">
        <xsl:text>&lt;image hidden="</xsl:text>
        <xsl:value-of select="./span[@class='hidebox']/input/@val"/>
        <xsl:text>" type="</xsl:text>
        <xsl:value-of select="./a[@class='image']/@type"/>
        <xsl:text>"&gt;
        </xsl:text>

        <xsl:text>&lt;filename&gt;</xsl:text>
        <xsl:value-of select="./a[@class='image']/@href"/>
        <xsl:text>&lt;/filename&gt;
        </xsl:text>

        <xsl:text>&lt;thumb&gt;</xsl:text>
        <xsl:value-of select="./a[@class='image']/img/@src"/>
        <xsl:text>&lt;/thumb&gt;
        </xsl:text>

        <xsl:text>&lt;description&gt;</xsl:text>
        <xsl:value-of select="./div[@class='desc']/input/@val"/>
        <xsl:text>&lt;/description&gt;
        </xsl:text>

        <xsl:text>&lt;date&gt;&lt;/date&gt;
        </xsl:text>

        <xsl:text>&lt;tags&gt;</xsl:text>
        <xsl:call-template name="tags">
        <xsl:with-param name="str" select="./span/input[@class='tags']/@val"/>
        </xsl:call-template>
        <xsl:text>&lt;/tags&gt;
        </xsl:text>

        <xsl:text>&lt;/image&gt;

        </xsl:text>
    </xsl:for-each>
    <xsl:text>&lt;/images&gt;
    &lt;/album&gt;</xsl:text>
</xsl:template>

<xsl:template name="tags">
    <xsl:param name="str"/>
    <xsl:choose>
    <xsl:when test = "contains($str, ',')">
        <xsl:text>
        &lt;tag&gt;</xsl:text>
        <xsl:value-of select="substring-before($str, ',')"/>
        <xsl:text>&lt;/tag&gt;</xsl:text>
        <xsl:call-template name="tags">
            <xsl:with-param name="str" select="substring-after($str, ',')"/>
        </xsl:call-template>
    </xsl:when>
    <xsl:when test = "$str = ''">
    </xsl:when>
    <xsl:otherwise>
        <xsl:text>
        &lt;tag&gt;</xsl:text>
        <xsl:value-of select="$str"/>
        <xsl:text>&lt;/tag&gt;
        </xsl:text>
    </xsl:otherwise>
    </xsl:choose>
</xsl:template>


</xsl:stylesheet>
